==> _private_chat-0.0.20.tar.gz: lib/chat_detail/bloc/chat_detail_event.dart <==
part of 'chat_detail_bloc.dart';

abstract class ChatDetailEvent extends Equatable {
  const ChatDetailEvent();

  @override
  List<Object> get props => [];
}

class ChatDetailInitialEvent extends ChatDetailEvent {
  ScrollController scrollController;
  TickerProvider tickerProvider;

  ChatDetailInitialEvent(this.scrollController, this.tickerProvider);
}

class ChatSendMessageEvent extends ChatDetailEvent {
  MessageType type;
  String text;
  File? image;

  Uint8List? imageData;
  String? imageExt;
  String? imageFileName;
  String? imageFileMime;
  int? assetFileDuration;

  ChatSendMessageEvent({
    required this.type,
    this.imageData,
    this.text = '',
    this.image,
    this.imageExt,
    this.imageFileMime,
    this.imageFileName,
    this.assetFileDuration,
  });
}

class ChatDetailLoadMoreMessagesEvent extends ChatDetailEvent {}

class ChatUpdateMessagesEvent extends ChatDetailEvent {}

class ChatDeleteMessagesEvent extends ChatDetailEvent {
  final int timestamp;
  const ChatDeleteMessagesEvent(this.timestamp);
}

class ChatDetailDisposeEvent extends ChatDetailEvent {}

class ChatDetailReplyMessagesEvent extends ChatDetailEvent {
  final Map<String, dynamic> repllyDoc;
  const ChatDetailReplyMessagesEvent(this.repllyDoc);
}

class ChatDetailEditMessagesEvent extends ChatDetailEvent {
  final Map<String, dynamic> editDoc;
  const ChatDetailEditMessagesEvent(this.editDoc);
}

class ChatDetailEditLastMessagesEvent extends ChatDetailEvent {}

class ChatDetailResetEditOrReplyEvent extends ChatDetailEvent {}

class ChatDetailSendReactionMessagesEvent extends ChatDetailEvent {
  Map<String, dynamic> doc;
  int value;
  ChatDetailSendReactionMessagesEvent(this.doc, this.value);
}

class ChatDetailUnsendReactionMessagesEvent extends ChatDetailEvent {
  Map<String, dynamic> doc;
  ChatDetailUnsendReactionMessagesEvent(this.doc);
}

class ChatDetailCopyMessageEvent extends ChatDetailEvent {
  final String text;

  const ChatDetailCopyMessageEvent(this.text);
}

class ChatDetailPastTextInputEvent extends ChatDetailEvent {
  final String? text;

  const ChatDetailPastTextInputEvent(this.text);
}

==> _private_chat-1.0.16.tar.gz: lib/chat_detail/bloc/chat_detail_event.dart <==
part of 'chat_detail_bloc.dart';

abstract class ChatDetailEvent extends Equatable {
  const ChatDetailEvent();

  @override
  List<Object> get props => [];
}

class ChatDetailInitialEvent extends ChatDetailEvent {
  final TickerProvider tickerProvider;

  const ChatDetailInitialEvent(this.tickerProvider);
}

class ChatSendMessageEvent extends ChatDetailEvent {
  final MessageType type;
  final String text;
  final File? image;

  final Uint8List? imageData;
  final String? imageExt;
  final String? imageFileName;
  final String? imageFileMime;
  final int? assetFileDuration;

  final Map? customData;

  const ChatSendMessageEvent({
    required this.type,
    this.imageData,
    this.text = '',
    this.image,
    this.imageExt,
    this.imageFileMime,
    this.imageFileName,
    this.assetFileDuration,
    this.customData,
  });
}

class ChatDetailLoadMoreMessagesEvent extends ChatDetailEvent {}

class ChatUpdateMessagesEvent extends ChatDetailEvent {}

class ChatDeleteMessagesEvent extends ChatDetailEvent {
  final int timestamp;
  const ChatDeleteMessagesEvent(this.timestamp);
}

class ChatDetailDisposeEvent extends ChatDetailEvent {}

class ChatDetailReplyMessagesEvent extends ChatDetailEvent {
  final Map<String, dynamic> repllyDoc;
  const ChatDetailReplyMessagesEvent(this.repllyDoc);
}

class ChatDetailEditMessagesEvent extends ChatDetailEvent {
  final Map<String, dynamic> editDoc;
  const ChatDetailEditMessagesEvent(this.editDoc);
}

class ChatDetailEditLastMessagesEvent extends ChatDetailEvent {}

class ChatDetailResetEditOrReplyEvent extends ChatDetailEvent {}

class ChatDetailSendReactionMessagesEvent extends ChatDetailEvent {
  final Map<String, dynamic> doc;
  final int value;
  const ChatDetailSendReactionMessagesEvent(this.doc, this.value);
}

class ChatDetailUnsendReactionMessagesEvent extends ChatDetailEvent {
  final Map<String, dynamic> doc;
  const ChatDetailUnsendReactionMessagesEvent(this.doc);
}

class ChatDetailCopyMessageEvent extends ChatDetailEvent {
  final String text;

  const ChatDetailCopyMessageEvent(this.text);
}

class ChatDetailPastTextInputEvent extends ChatDetailEvent {
  final String? text;

  const ChatDetailPastTextInputEvent(this.text);
}
